==> flume-0.0.1.tar.gz: flume-0.0.1/flume/adapters/stdio.py <==
"""
stdio adapter
"""
import sys

from flume.adapters.adapter import adapter
from flume.adapters import streamers
from flume.point import Point
from flume import logger, moment


class stdio(adapter):
    """
    stdio adapter

    Used to read/write points from standard IO which includes the stdin,
    stdout and stderr, but can also be used to read/write points to a
    file on the filesystem
    """

    name = 'stdio'

    stdout = sys.stdout
    stdin = sys.stdin

    def __init__(self,
                 time='time',
                 format='jsonl',
                 file=None,
                 **kwargs):
        self.time = time
        self.streamer = streamers.get_streamer(format, **kwargs)
        self.file = file

    def __read(self, stream):
        for point in self.streamer.read(stream):
            if self.time in point.keys():
                point['time'] = moment.date(point[self.time])

                if self.time != 'time':
                    del point[self.time]

                yield [Point(**point)]

            else:
                yield [Point(**point)]

    def read(self):
        if self.file is None:
            for point in self.__read(stdio.stdin):
                yield point

        else:
            with open(self.file, 'r') as stream:
                for point in self.__read(stream):
                    yield point

    def write(self, points):
        if self.file is None:
            self.streamer.write(stdio.stdout, points)

        else:
            with open(self.file, 'a') as stream:
                self.streamer.write(stream, points)

    def eof(self):
        self.streamer.eof(stdio.stdout)

==> flume-0.3.2.tar.gz: flume-0.3.2/flume/adapters/stdio.py <==
"""
stdio adapter
"""
import sys

from flume.adapters.adapter import adapter
from flume.adapters import streamers
from flume.point import Point


class InputStream(object):
    """
    Override the behaviour of readlines which doesn't actually stream data but
    attempts to read the whole input and break it into individual lines. We want
    the input to stream line by line and not block the pipeline.
    """

    def __init__(self, file):
        self.file = file

    def read(self, size=1024):
        return self.file.read(size=1024)

    def readlines(self):

        while True:
            line = self.file.readline()

            if not line:
                break

            yield line

class stdio(adapter):
    """
    stdio adapter

    Used to read/write points from standard IO which includes the stdin,
    stdout and stderr, but can also be used to read/write points to a
    file on the filesystem
    """

    name = 'stdio'

    stdout = sys.stdout
    stdin = sys.stdin

    def __init__(self,
                 format='jsonl',
                 file=None,
                 **kwargs):
        self.streamer = streamers.get_streamer(format, **kwargs)
        self.file = file

    def read(self):
        if self.file is None:
            for point in self.streamer.read(InputStream(stdio.stdin)):
                yield [Point(**point)]

        else:
            with open(self.file, 'r') as stream:
                stream = InputStream(stream)
                for point in self.streamer.read(stream):
                    yield [Point(**point)]

    def write(self, points):
        if self.file is None:
            self.streamer.write(stdio.stdout, points)

        else:
            with open(self.file, 'a') as stream:
                self.streamer.write(stream, points)

    def eof(self):
        self.streamer.eof(stdio.stdout)
